;---------------------------------------------------------------------------------------------------------------------------------------
function get_refdate, scenario, year=year, month=month, day=day, doy=doy, julian_day=julian_day, path=path, refdoy=refdoy, refjul=refjul
;---------------------------------------------------------------------------------------------------------------------------------------
; RETURN VALUE
; get_refdate returns the reference date for all scenarios between
; 1/1/1960 and 31/12/2100
; array [reference year, reference month, refeference day], or [reference year,reference doy] if refdoy
; is set, or scalar reference Julian day if julian is set.
;
; ARGUMENTS:
; scenario      : 'REF' or 'SOLARTREND'
;
; KEYWORDS: 
; year          : actual year
; month         : actual month
; day           : actual day
; doy           : actual day of the year 
; julian_day    : actual Julian day 
; path (string) : directory path of nc files ("./" if empty)
;
  if strupcase(strtrim(scenario,2)) eq 'REF' then cscen='REF_C2' else if $
     strupcase(strtrim(scenario,2)) eq 'SOLARTREND' then cscen='SEN_solar_trend' else begin
     print, 'Error: scenario does not exist'
     stop
  endelse
  if keyword_set(julian_day) then jul=round(julian_day) else begin 
     if keyword_set(doy) then begin
        if not keyword_set(year) then begin
           print, 'Error: year must be given with doy'
           stop
        endif
        jul=julday(1,1,year)+doy-1
     endif else begin
        if not keyword_set(year) and not keyword_set(month) and not keyword_set(day) then begin
           print, 'Error: year, month, day must be given'
           stop
        endif
        jul=julday(month,day,year)
     endelse
  endelse    
  if keyword_set(path) then cpath = path else cpath='' 
  ncf=NCDF_OPEN(strtrim(cpath)+'dates_'+cscen+'.nc',/NOWRITE)
  ivar=NCDF_VARID(ncf, 'time')
  NCDF_VARGET, ncf, ivar,time
  ivar=NCDF_VARID(ncf, 'ref_year')
  NCDF_VARGET, ncf, ivar, ry
  if keyword_set(refdoy) then begin
     ivar=NCDF_VARID(ncf, 'ref_doy')
     NCDF_VARGET, ncf, ivar,rd
  endif else if keyword_set(refjul) then begin
     ivar=NCDF_VARID(ncf, 'ref_time')
     NCDF_VARGET, ncf, ivar,rt
  endif else begin
     ivar=NCDF_VARID(ncf, 'ref_month')
     NCDF_VARGET, ncf, ivar,rm 
     ivar=NCDF_VARID(ncf, 'ref_day')
     NCDF_VARGET, ncf, ivar,rd
  endelse
  NCDF_CLOSE,ncf
  if max(jul) gt max(time)+0.1 or min(jul) lt min(time)-0.1  then begin
     print, 'Error: date not given in file'
     stop
  endif else begin
     ind=value_locate(time,jul)
     if keyword_set(refjul) then refdate=rt(ind) else if $
        keyword_set(refdoy) then refdate=[ry(ind),rd(ind)] else $ 
           refdate=[ry(ind),rm(ind),rd(ind)]
  endelse
  return,refdate
end 
